From 5400ae438c52cd7c21e1ce416e0670ebd2c74c17 Mon Sep 17 00:00:00 2001
From: Benjamin Drung <benjamin.drung@cloud.ionos.com>
Date: Wed, 11 Nov 2020 10:27:21 +0100
Subject: Fix spelling error of mismatch

Signed-off-by: Benjamin Drung <benjamin.drung@cloud.ionos.com>
---
 ibdiag/src/ibdebug_if.tcl               |   4 +-
 ibdm/Clusters/topo2subnet               |   2 +-
 ibdm/doc/ibdmsh.pod                     |   2 +-
 ibdm/ibdm/TopoMatch.cpp                 | 106 ++++++++++++------------
 ibdm/src/test_topo_match.cpp            |   4 +-
 ibis/tests/ibvs_test.tcl                |   8 +-
 ibmgtsim/tests/osmLidAssignment.sim.tcl |   2 +-
 ibmgtsim/tests/osmStress.sim.tcl        |   2 +-
 8 files changed, 65 insertions(+), 65 deletions(-)

diff --git a/ibdiag/src/ibdebug_if.tcl b/ibdiag/src/ibdebug_if.tcl
index cdc389d..df626f1 100644
--- a/ibdiag/src/ibdebug_if.tcl
+++ b/ibdiag/src/ibdebug_if.tcl
@@ -2014,7 +2014,7 @@ proc inform { msgCode args } {
 	    set nodeName  [lindex $args 0]
 	    set inb    [lindex $args 1]
 	    set outb   [lindex $args 2]
-	    append msgText "Missmatching In-Bound ($inb) and Out-Bound ($outb) PKey enforcement on switch $nodeName"
+	    append msgText "Mismatching In-Bound ($inb) and Out-Bound ($outb) PKey enforcement on switch $nodeName"
 	}
         "-W-ibdiagnet:PKeys.switch.missing.pkey" {
 	    set name   [lindex $args 0]
@@ -2054,7 +2054,7 @@ proc inform { msgCode args } {
 	    foreach {gPKey pkey} $args {break}
 	    set pk1 [format 0x%04x $gPKey]
 	    set pk2 [format 0x%04x $pKey]
-	    append msgText "Missmatching Multicast Group PKey:$pk1 and MGID Pkey:$pk2"
+	    append msgText "Mismatching Multicast Group PKey:$pk1 and MGID Pkey:$pk2"
 	}
         "-W-ibdiagnet:ipoib.cantJoin" {
 	    foreach {name rate gRate} $args {break}
diff --git a/ibdm/Clusters/topo2subnet b/ibdm/Clusters/topo2subnet
index f56048d..8fa31e3 100755
--- a/ibdm/Clusters/topo2subnet
+++ b/ibdm/Clusters/topo2subnet
@@ -48,7 +48,7 @@ Description:
 subnet.lst file (in local dir) to match the specified topology.
 It 'invents' guids and lids sequentially.
 
-TODO: Randomize missmatches ...
+TODO: Randomize mismatches ...
 "
 
 ###########################################################################
diff --git a/ibdm/doc/ibdmsh.pod b/ibdm/doc/ibdmsh.pod
index 599a5ad..1386d5e 100644
--- a/ibdm/doc/ibdmsh.pod
+++ b/ibdm/doc/ibdmsh.pod
@@ -594,7 +594,7 @@ Trace a path following the LFT updating the hops and node list variables
 
 =head2 Topology Matching Utilities
 
-The following utilities matches two fabrics providing both missmatch messages and a unified fabric
+The following utilities matches two fabrics providing both mismatch messages and a unified fabric
 
 =over
 
diff --git a/ibdm/src/test_topo_match.cpp b/ibdm/src/test_topo_match.cpp
index 5e546a7..867fa35 100644
--- a/ibdm/src/test_topo_match.cpp
+++ b/ibdm/src/test_topo_match.cpp
@@ -64,9 +64,9 @@ show_help() {
        << "\n"
        << "Description:\n"
        << "This tool compares a topology file and a discovered listing of"
-	 << "subnet.lst/ibdiagnet.lst and reports missmatches.\n"
+	 << "subnet.lst/ibdiagnet.lst and reports mismatches.\n"
 	 << "Two different algorithms provided:\n"
-	 << "Using the -e option is more suitible for MANY missmatches\n"
+	 << "Using the -e option is more suitible for MANY mismatches\n"
 	 << "it applies less heuristics and provide details about the match.\n"
 	 << "Providing the -s, -p and -g starts a detailed heuristics that\n"
 	 << "should be used when only small number of changes are expected.\n"
diff --git a/ibis/tests/ibvs_test.tcl b/ibis/tests/ibvs_test.tcl
index bf3c7e7..7a4d68c 100755
--- a/ibis/tests/ibvs_test.tcl
+++ b/ibis/tests/ibvs_test.tcl
@@ -221,7 +221,7 @@ for {set i 0} {$i < $numLoops} {incr i} {
                set prev [lindex [array get DATA$d $i] 1]
                set this [assoc data$i $data]
                if {$prev != $this} {
-                  puts "-E- Missmatch on set:$d data:$i $prev != $this"
+                  puts "-E- Mismatch on set:$d data:$i $prev != $this"
                   incr anyError
                }
             }
@@ -242,7 +242,7 @@ for {set i 0} {$i < $numLoops} {incr i} {
                set prev [lindex [array get DATA$d $i] 1]
                set this [assoc data$i $data]
                if {$prev != $this} {
-                  puts "-E- Missmatch on set:$d data:$i $prev != $this"
+                  puts "-E- Mismatch on set:$d data:$i $prev != $this"
                   incr anyError
                }
             }
@@ -272,7 +272,7 @@ for {set i 0} {$i < $numLoops} {incr i} {
             set prev [lindex $newWords $i]
             set this [assoc data$i $data]
             if {$prev != $this} {
-               puts "-E- Missmatch read back of written data-set:$d data:$i $prev != $this"
+               puts "-E- Mismatch read back of written data-set:$d data:$i $prev != $this"
                incr anyError
             }
          }
@@ -291,7 +291,7 @@ for {set i 0} {$i < $numLoops} {incr i} {
             set prev [lindex $oldWords $i]
             set this [assoc data$i $data]
             if {$prev != $this} {
-               puts "-E- Missmatch read back of reverted data-set:$d data:$i $prev != $this"
+               puts "-E- Mismatch read back of reverted data-set:$d data:$i $prev != $this"
                incr anyError
             }
          }
diff --git a/ibmgtsim/tests/osmLidAssignment.sim.tcl b/ibmgtsim/tests/osmLidAssignment.sim.tcl
index a765aa3..0ff9d54 100644
--- a/ibmgtsim/tests/osmLidAssignment.sim.tcl
+++ b/ibmgtsim/tests/osmLidAssignment.sim.tcl
@@ -698,7 +698,7 @@ proc checkLidValues {fabric lmc} {
       }
    }
    if {$numErrs} {
-      puts "-E- Got $numErrs missmatches in lid assignment out of $numPorts ports"
+      puts "-E- Got $numErrs mismatches in lid assignment out of $numPorts ports"
    } else {
       puts "-I- scanned $numPorts ports with no error"
    }
diff --git a/ibmgtsim/tests/osmStress.sim.tcl b/ibmgtsim/tests/osmStress.sim.tcl
index 4d1a533..7b1b876 100755
--- a/ibmgtsim/tests/osmStress.sim.tcl
+++ b/ibmgtsim/tests/osmStress.sim.tcl
@@ -546,7 +546,7 @@ proc checkLidValues {fabric lmc} {
       }
    }
    if {$numErrs} {
-      puts "-E- Got $numErrs missmatches in lid assignment out of $numPorts ports"
+      puts "-E- Got $numErrs mismatches in lid assignment out of $numPorts ports"
    } else {
       puts "-I- scanned $numPorts ports with no error"
    }
diff --git a/ibdm/ibdm/TopoMatch.cpp b/ibdm/ibdm/TopoMatch.cpp
index dd2bfc5..434bb3c 100644
--- a/ibdm/ibdm/TopoMatch.cpp
+++ b/ibdm/ibdm/TopoMatch.cpp
@@ -44,7 +44,7 @@ spec = The fabric as specified in either a topology file or cables file.
 
 Through the matching algorithm:
 1. The specification fabric get guids annotations.
-2. Missmatches are being formatted into a text report.
+2. Mismatches are being formatted into a text report.
 
 After Matching a Merger can be run to create the merged fabric.
 This fabric only includes the discovered nodes but uses the
@@ -105,7 +105,7 @@ TopoMatchPorts(IBPort *p_sPort,
     }
     if (p_sPort->num != p_dPort->num) {
         if (doDiag)
-            diag << "Port number missmatch found. The port:" << p_sPort->getName()
+            diag << "Port number mismatch found. The port:" << p_sPort->getName()
             << " != discovered:" << p_dPort->num << endl;
         return 0;
     }
@@ -280,11 +280,11 @@ TopoQalifyNodesMatching(IBNode *p_sNode, IBNode *p_dNode)
             if (numMissed <= maxMissed)
                 cout << "-V- Qualified Nodes:" << p_sNode->name
                 << " to:" << p_dNode->name << " with:" << numMissed
-                << " missmatches!" <<endl;
+                << " mismatches!" <<endl;
             else
                 cout << "-V- Disqualified Nodes:" << p_sNode->name
                 << " to:" << p_dNode->name << " due to:" << numMissed
-                << " missmatches!\n" << tmpDiag.str() << endl;
+                << " mismatches!\n" << tmpDiag.str() << endl;
     return numMissed <= maxMissed;
 }
 
@@ -367,16 +367,16 @@ TopoDoBFSAndMatch(IBNode *p_sNodeAnchor,  // Starting node on the specification
                 continue;
 
             // do not rush into matching - double check all the nodes ports ...
-            int anyMissmatch = 0;
+            int anyMismatch = 0;
             if (p_node1->numPorts != p_node2->numPorts)
                 continue;
-                for (unsigned int pn = 1; !anyMissmatch && (pn <= p_node1->numPorts);
+                for (unsigned int pn = 1; !anyMismatch && (pn <= p_node1->numPorts);
                         pn++) {
                     IBPort *p_dPort = p_node1->getPort(pn);
                     IBPort *p_sPort = p_node2->getPort(pn);
 
                     if (! TopoMatchPorts(p_sPort, p_dPort, 1, diag)) {
-                        anyMissmatch++;
+                        anyMismatch++;
                         if (FabricUtilsVerboseLevel & FABU_LOG_VERBOSE)
                             cout << "-V- Matched node:" <<  (*nI).first
                             << " by name - but some ports are different." << endl;
@@ -386,7 +386,7 @@ TopoDoBFSAndMatch(IBNode *p_sNodeAnchor,  // Starting node on the specification
                         IBNode *p_dRemNode = p_dPort->p_remotePort->p_node;
                         IBNode *p_sRemNode = p_sPort->p_remotePort->p_node;
                         if (! TopoQalifyNodesMatching(p_sRemNode, p_dRemNode)) {
-                            anyMissmatch++;
+                            anyMismatch++;
                             if (FabricUtilsVerboseLevel & FABU_LOG_VERBOSE)
                                 cout << "-V- Disqualified start nodes match:"
                                 << p_node1->name << " by rem nodes" << endl;
@@ -547,7 +547,7 @@ TopoBFSAndMatchFromPorts(IBPort *p_sPort, // Starting port on the specification
 
 
 //////////////////////////////////////////////////////////////////////////////
 // Second step in matching - refine missmatched nodes:
 // Based on the previous matching - produce a set of all spec nodes
 // that are connected to other matched spec nodes.
 // Then go over all these nodes and produce a "best fit" match for them:
@@ -680,7 +680,7 @@ TopoMatchSpecNodesByAdjacentNode(IBFabric *p_sFabric)
 
 
 //////////////////////////////////////////////////////////////////////////////
 // Report missmatched nodes by examining entire system and looking for
 // all system and then a single board (matching regexp).
 // So the report will be optimized:
 // If the entire system is missing - report only at this level
@@ -691,7 +691,7 @@ TopoReportMismatchedNode(IBNode *p_node,
         int reportMissing, // 0 = reportExtra ...
         stringstream &diag)
 {
-    int anyMissmatch = 0;
+    int anyMismatch = 0;
     int MaxConnRep = 12;
     // we assume if a previous check was done we would have
     // never been called since the "reported" mark would have been set
@@ -789,7 +789,7 @@ TopoReportMismatchedNode(IBNode *p_node,
             if (numRep == MaxConnRep) diag << "   ..." << endl;
             diag << endl;
         }
-        anyMissmatch++;
+        anyMismatch++;
 
         // also we do not need any more checks on this system
         for (map_str_pnode::iterator nI = p_system->NodeByName.begin();
@@ -805,7 +805,7 @@ TopoReportMismatchedNode(IBNode *p_node,
             diag << "Extra System Board:" << nodeBoardName << endl;
             diag << endl;
         }
-        anyMissmatch++;
+        anyMismatch++;
 
         for (list< IBNode *>::iterator nI = boardNodes.begin();
                 nI != boardNodes.end(); nI++) {
@@ -860,26 +860,26 @@ TopoReportMismatchedNode(IBNode *p_node,
                 diag << "   ..." << endl;
             diag << endl;
         }
-        anyMissmatch++;
+        anyMismatch++;
 
         TopoMarkNodeAsReported(p_node);
     }
-    return(anyMissmatch);
+    return(anyMismatch);
 }
 
 
 // Given two matching nodes - report un-matching links.
 // To avoid duplicated reporting:
 // * We only report missmatching links to matched nodes.
 // * We only report link to nodes with bigger pointer value
 // RETURN number of missmatches
 static int
 TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
         IBNode *p_dNode,
         stringstream &diag)
 {
-    int anyMissmatch = 0;
-    // missmatch is when port numbers differ
+    int anyMismatch = 0;
+    // mismatch is when port numbers differ
     // or the remote node is not the same.
     IBPort *p_sPort, *p_dRemPort;
     IBPort *p_dPort, *p_sRemPort;
@@ -924,7 +924,7 @@ TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
                        << " to:" << p_actRemSNode->name << "/P" << p_dRemPort->num
                        << " instead of:" << p_sRemPort->getName() << endl;
                 }
-                anyMissmatch++;
+                anyMismatch++;
             } else {
                 // make sure same port remote number
                 if (p_dRemPort->num != p_sRemPort->num) {
@@ -943,7 +943,7 @@ TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
                          << " to:" << p_actRemSNode->name << "/P" << p_dRemPort->num
                          << " instead of:" << p_sRemPort->getName() << endl;
                     }
-                    anyMissmatch++;
+                    anyMismatch++;
                 }
             }
             // anyway make sure we got the width and speed.
@@ -951,13 +951,13 @@ TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
                 diag << "Wrong link width on:" << p_sPort->getName()
                      << ". Expected:" << width2char(p_sPort->width)
                      << " got:" << width2char(p_dPort->width) << endl;
-                anyMissmatch++;
+                anyMismatch++;
             }
             if (p_sPort->speed != p_dPort->speed) {
                 diag << "Wrong link speed on:" << p_sPort->getName()
                      << ". Expected:" << speed2char(p_sPort->speed)
                      << " got:" << speed2char(p_dPort->speed) << endl;
-                anyMissmatch++;
+                anyMismatch++;
             }
             // done with the case both spec and dicsovered links exists
         } else if (!p_dRemPort && p_sRemPort) {
@@ -987,7 +987,7 @@ TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
                        << " to:" << p_sRemPort->getName() << endl;
                 }
             }
-            anyMissmatch++;
+            anyMismatch++;
         } else if (p_dRemPort && !p_sRemPort) {
             // Only a discovered link exists:
 
@@ -1045,25 +1045,25 @@ TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
                 diag << "Extra internal Link connecting:" << specPortName
                         << " to:" << portName << endl;
             }
-            anyMissmatch++;
+            anyMismatch++;
         }
     }
-    if (anyMissmatch)
+    if (anyMismatch)
         diag << endl;
-  return(anyMissmatch);
+  return(anyMismatch);
 }
 
 
 // Report Topology Missmatched and Build the Merged Fabric:
 static int
-TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the specification fabrric
+TopoReportMismatches(IBNode *p_sNodeAnchor,            // Starting node on the specification fabrric
         IBNode *p_dNodeAnchor,
         stringstream &diag)
 {
     IBNode *p_sNode, *p_dNode;
-    int anyMissmatchedSpecNodes = 0;
-    int anyMissmatchedDiscNodes = 0;
-    int anyMissmatchedLinks = 0;
+    int anyMismatchedSpecNodes = 0;
+    int anyMismatchedDiscNodes = 0;
+    int anyMismatchedLinks = 0;
 
     // since we do not want to report errors created by previous node failure
     // to discover or match we will BFS from the start ports.
@@ -1082,7 +1082,7 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
         // we got in here only with matching nodes:
         p_sNode = (IBNode *)p_dNode->appData1.ptr;
         if (!p_sNode) {
-            cerr << "How did we get in BFS with missmatching nodes!" << endl;
+            cerr << "How did we get in BFS with mismatching nodes!" << endl;
             exit (1);
         }
 
@@ -1107,7 +1107,7 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
             // if the remote spec node is not marked matched:
             if (!p_sRemPort->p_node->appData1.ptr) {
                 if (TopoReportMismatchedNode(p_sRemPort->p_node, 1, diag))
-                    anyMissmatchedSpecNodes++;
+                    anyMismatchedSpecNodes++;
             } else {
                 // mark as visited.
                 TopoMarkNodeAsReported(p_sRemPort->p_node);
@@ -1121,7 +1121,7 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
         }           // all ports
     }           // next nodes available...
 
-    if (anyMissmatchedSpecNodes)
+    if (anyMismatchedSpecNodes)
         diag << endl;
 
     IBFabric *p_dFabric = p_dNodeAnchor->p_fabric;
@@ -1135,7 +1135,7 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
         diag << "Even starting nodes do not match! "
                 << "Expected:" << p_sNodeAnchor->name
                 << " but it is probably not connected correctly." <<  endl;
-        anyMissmatchedDiscNodes++;
+        anyMismatchedDiscNodes++;
     }
 
     // we track visited nodes in here by clearing their visited bits
@@ -1159,12 +1159,12 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
 
             IBNode *p_node = p_dRemPort->p_node;
 
             // we only care about missmatched discovered nodes
             if (! p_node->appData1.ptr) {
                 // if not already visited.
                 if (! TopoIsNodeMarkedAsReported(p_node))
                     if (TopoReportMismatchedNode(p_node, 0, diag))
-                        anyMissmatchedDiscNodes++;
+                        anyMismatchedDiscNodes++;
             } else {
                 // if not already visited.
                 if (! TopoIsNodeMarkedAsReported(p_node))
@@ -1184,26 +1184,26 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
         TopoMarkNodeAsReported(p_dNode);
     }           // next nodes available...
 
-    if (anyMissmatchedDiscNodes)
+    if (anyMismatchedDiscNodes)
         diag << endl;
 
     // finaly we want to report any missmatched cables between matching nodes
     for (map_str_pnode::iterator nI = p_dFabric->NodeByName.begin();
             nI != p_dFabric->NodeByName.end(); nI++) {
         p_dNode = (*nI).second;
         p_sNode = (IBNode *)p_dNode->appData1.ptr;
         if ( p_sNode ) {
             // report any missmatched links on this node.
             if (TopoReportMatchedNodesUnMatchingLinks(p_sNode, p_dNode, diag))
-                anyMissmatchedLinks++;
+                anyMismatchedLinks++;
         }
     }
 
-    if (anyMissmatchedLinks)
+    if (anyMismatchedLinks)
         diag << endl;
-    return anyMissmatchedLinks +
-    anyMissmatchedDiscNodes +
-    anyMissmatchedSpecNodes;
+    return anyMismatchedLinks +
+    anyMismatchedDiscNodes +
+    anyMismatchedSpecNodes;
 }
 
 
@@ -1303,7 +1303,7 @@ TopoMatchFabrics(IBFabric   *p_sFabric,         // The specification fabric
         status = TopoBFSAndMatchFromNodes(p_sNode, p_dNode, tmpDiag);
     }
     if (status) {
-        cout << "-W- Topology Matching First Phase Found Missmatches:\n"
+        cout << "-W- Topology Matching First Phase Found Mismatches:\n"
                 << tmpDiag.str() << endl;
     }
 
@@ -1311,7 +1311,7 @@ TopoMatchFabrics(IBFabric   *p_sFabric,         // The specification fabric
     // and try to map the unmatched.
     TopoMatchSpecNodesByAdjacentNode(p_sFabric);
 
-    if (TopoReportMissmatches(p_sNode, p_dNode, diag))
+    if (TopoReportMismatches(p_sNode, p_dNode, diag))
         status = 1;
 
  Exit:
@@ -1461,7 +1461,7 @@ TopoCopyLinkToMergedFabric(IBFabric *p_mFabric,
     } else {
 /*
         // The following error messages are actually not required at
         // all. If there is a missmatch on an internal node this will happen.
         if (p_remPort->p_sysPort) {
             cout << "-E- Linking:" << p_mPort->getName() << " to:"
                     << p_remPort->p_node->name
@@ -1798,7 +1798,7 @@ CheckMatchingCAPortsToMatchingSwPortNums(IBFabric *p_sFabric, IBFabric *p_dFabri
 // try all ports and look for remote side switches
 // if remote ports match collect all the switches reached
 // now go over all reached switches and validate back all connections
 // to matched switches - report missmatches or report the new set
 // return the number of new matches found
 static int
 TopoMatchSwitches(IBFabric *p_sFabric,
@@ -2001,7 +2001,7 @@ TopoMatchSwitches(IBFabric *p_sFabric,
 
 
 // go over entire fabric from edges and in and report
 // each missmatch - do not propogate inwards through missmatches
 static int
 BfsFromEdgReportingMatcStatus(IBFabric *p_sFabric, IBFabric *p_dFabric,
         stringstream &s)
@@ -2077,7 +2077,7 @@ BfsFromEdgReportingMatcStatus(IBFabric *p_sFabric, IBFabric *p_dFabric,
                         p_sActRemNode->getPort(p_dPort->p_remotePort->num);
                 // so they must be same nodes...
                 if (p_sActRemNode != p_sRemNode) {
-                    badMsg << "-E- Missmatch: port:" << p_sPort->getName()
+                    badMsg << "-E- Mismatch: port:" << p_sPort->getName()
                             << " should be connected to:"
                             <<  p_sPort->p_remotePort->getName()
                             << " but connects to:" << p_sActRemPort->getName() << endl;
@@ -2088,7 +2088,7 @@ BfsFromEdgReportingMatcStatus(IBFabric *p_sFabric, IBFabric *p_dFabric,
                 // now we know they both point to same switch - check the port
                 // connection and properties
                 if (p_sPort->p_remotePort->num != p_dPort->p_remotePort->num) {
-                    badMsg << "-E- Missmatch: port " << p_sPort->getName()
+                    badMsg << "-E- Mismatch: port " << p_sPort->getName()
                             << " should be connected to:"
                             <<  p_sPort->p_remotePort->getName()
                             << " but connects to port: "
@@ -547,7 +547,7 @@ TopoBFSAndMatchFromPorts(IBPort *p_sPort, // Starting port on the specification
 
 //////////////////////////////////////////////////////////////////////////////
-// Second step in matching - refine missmatched nodes:
+// Second step in matching - refine mismatched nodes:
 // Based on the previous matching - produce a set of all spec nodes
 // that are connected to other matched spec nodes.
@@ -680,7 +680,7 @@ TopoMatchSpecNodesByAdjacentNode(IBFabric *p_sFabric)
 
 //////////////////////////////////////////////////////////////////////////////
-// Report missmatched nodes by examining entire system and looking for
+// Report mismatched nodes by examining entire system and looking for
 // all system and then a single board (matching regexp).
 // So the report will be optimized:
@@ -860,26 +860,26 @@ TopoReportMismatchedNode(IBNode *p_node,
 // Given two matching nodes - report un-matching links.
 // To avoid duplicated reporting:
-// * We only report missmatching links to matched nodes.
+// * We only report mismatching links to matched nodes.
 // * We only report link to nodes with bigger pointer value
@@ -860,26 +860,26 @@ TopoReportMismatchedNode(IBNode *p_node,
 // * We only report link to nodes with bigger pointer value
-// RETURN number of missmatches
+// RETURN number of mismatches
 static int
 TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
@@ -1045,25 +1045,25 @@ TopoReportMatchedNodesUnMatchingLinks(IBNode *p_sNode,
 
 
-// Report Topology Missmatched and Build the Merged Fabric:
+// Report Topology Mismatched and Build the Merged Fabric:
 static int
@@ -1159,12 +1159,12 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
             IBNode *p_node = p_dRemPort->p_node;
 
-            // we only care about missmatched discovered nodes
+            // we only care about mismatched discovered nodes
             if (! p_node->appData1.ptr) {
                 // if not already visited.
@@ -1184,26 +1184,26 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
         diag << endl;
 
-    // finaly we want to report any missmatched cables between matching nodes
+    // finaly we want to report any mismatched cables between matching nodes
     for (map_str_pnode::iterator nI = p_dFabric->NodeByName.begin();
             nI != p_dFabric->NodeByName.end(); nI++) {
@@ -1184,26 +1184,26 @@ TopoReportMissmatches(IBNode *p_sNodeAnchor,            // Starting node on the
         p_sNode = (IBNode *)p_dNode->appData1.ptr;
         if ( p_sNode ) {
-            // report any missmatched links on this node.
+            // report any mismatched links on this node.
             if (TopoReportMatchedNodesUnMatchingLinks(p_sNode, p_dNode, diag))
@@ -1461,7 +1461,7 @@ TopoCopyLinkToMergedFabric(IBFabric *p_mFabric,
 /*
         // The following error messages are actually not required at
-        // all. If there is a missmatch on an internal node this will happen.
+        // all. If there is a mismatch on an internal node this will happen.
         if (p_remPort->p_sysPort) {
             cout << "-E- Linking:" << p_mPort->getName() << " to:"
@@ -1798,7 +1798,7 @@ CheckMatchingCAPortsToMatchingSwPortNums(IBFabric *p_sFabric, IBFabric *p_dFabri
 // if remote ports match collect all the switches reached
 // now go over all reached switches and validate back all connections
-// to matched switches - report missmatches or report the new set
+// to matched switches - report mismatches or report the new set
 // return the number of new matches found
 static int
@@ -2001,7 +2001,7 @@ TopoMatchSwitches(IBFabric *p_sFabric,
 
 // go over entire fabric from edges and in and report
-// each missmatch - do not propogate inwards through missmatches
+// each mismatch - do not propogate inwards through mismatches
 static int
 BfsFromEdgReportingMatcStatus(IBFabric *p_sFabric, IBFabric *p_dFabric,
-- 
2.25.1

